@@ -65,10 +65,16 @@ def monkeypatch_all(*args, **kwds):
 with monkeypatch_all():
     import dns.resolver
 
+#: .. versionadded:: 0.3.19
+#:
 #: This is an instance of `dns.resolver.Resolver()
 #: <http://www.dnspython.org/docs/1.11.1/dns.resolver.Resolver-class.html>`_
-#: monkey-patched with :mod:`gevent`. Additionally it has its ``retry_servfail``
-#: attribute set to ``True``.
+#: monkey-patched with :mod:`gevent`. Additionally it has its
+#: ``retry_servfail`` attribute set to ``True``.
+#:
+#: Built-in slimta modules use this resolver for custom DNS queries, such as
+#: *MX* record lookup. You can modify attributes such as ``timeout`` or
+#: ``lifetime`` to control query behavior.
 dns_resolver = dns.resolver.Resolver()
 dns_resolver.retry_servfail = True
 
@@ -90,7 +96,7 @@ def build_auth_from_dict(dict, lower_case=False, only_verify=True):
     """
     class CustomAuth(Auth):
 
-        def verify_secret(self, authcid, secret, authzid):
+        def verify_secret(self, authcid, secret, authzid=None):
             username = authcid.lower() if lower_case else authcid
             try:
                 assert dict[username] == secret
@@ -98,7 +104,7 @@ def build_auth_from_dict(dict, lower_case=False, only_verify=True):
                 raise CredentialsInvalidError()
             return username
 
-        def get_secret(self, authcid, authzid):
+        def get_secret(self, authcid, authzid=None):
             username = authcid.lower() if lower_case else authcid
             try:
                 return dict[username], username
